@@ -1,5 +1,5 @@
 """
-Version information for `pip-audit`.
+The `pip_audit` APIs.
 """
 
 from pip_audit._version import __version__  # noqa: F401
